<!--
  ~ Copyright (c) Jupyter Development Team.
  ~ Distributed under the terms of the Modified BSD License.
-->

<div role="contentinfo">
    <p>
        <a href="{{ pathto('privacy_policies') }}">Privacy Policies</a>
    </p>
</div>
