"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[5454],{83073:(e,a,p)=>{p.d(a,{createArchitectureServices:()=>t.S});var t=p(31109);var c=p(11254)}}]);