"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[7865],{77865:(a,e,p)=>{p.d(e,{createInfoServices:()=>t.v});var t=p(78572);var c=p(11254)}}]);