"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[8968],{18968:(e,a,p)=>{p.d(a,{createTreemapServices:()=>t.d});var t=p(33308);var r=p(11254)}}]);